using System;
using NUnit.Framework;
using NUnit.Framework.SyntaxHelpers;

namespace rorovovaror
{
	[TestFixture]
	public class rorovovaror_test
	{		
		/// <summary>
		/// Pairs such that enrov(pair[0]) == pair[1] and derov(pair[1]) == pair[0].
		/// </summary>
		string[][] testPairs =  new string[][] {
			new string[] {"rov", "rorovov"},
			new string[] {"Test",      "TOTesostot"},
			new string[] {"IBM",       "IBOBMOM"},
			new string[] {"fooBAR",    "fofooBOBAROR"},
			new string[] {"XYZZYX",    "XOXYZOZZOZYXOX"},
			new string[] {"emacs",     "emomacocsos"},
			new string[] {"5",         "5"},
		};
		
		
		/// <summary>
		/// Tricky pairs with lots of o's etc.
		/// </summary>
		string[][] trickyPairs =  new string[][] {	
			new string[] {"Bob",       "BOBobob"},
			new string[] {"robot",     "rorobobotot"},
			new string[] {"ror",       "rororor"},
			new string[] {"kalasfint", "kokalolasosfofinontot"},
			new string[] {"",          ""},
			new string[] {null,        null},
		};
			
		/// <summary>
		/// Test the adding of o's.
		/// </summary>
		[Test]
		public void TestEnrov()
		{
			string i, o;
			for (int j = 0; j < testPairs.Length; j++)
			{
				i = testPairs[j][0];
				o = testPairs[j][1];
				Assert.IsTrue(rovar.enrov(i) == o, "{0} -> {1} == {2}?", i, o, rovar.enrov(i));
			}
		}
		
		/// <summary>
		/// Test the removal of o's.
		/// </summary>
		[Test]
		public void TestDerov()
		{
			string i, o;
			for (int j = 0; j < testPairs.Length; j++)
			{
				i = testPairs[j][1];
				o = testPairs[j][0];
				Assert.IsTrue(rovar.derov(i) == o, "{0} -> {1} == {2}?", i, o, rovar.derov(i));
			}
		}
		
		
		/// <summary>
		/// Test tricky pairs.
		/// </summary>
		[Test]
		public void TestTricky()
		{
			string i, o;
			for (int j = 0; j <  trickyPairs.Length; j++)
			{
				i = trickyPairs[j][0];
				o = trickyPairs[j][1];
				Assert.IsTrue(rovar.enrov(i) == o, "{0} -> {1} == {2} ?", i, o, rovar.enrov(i));
				Assert.IsTrue(rovar.derov(o) == i, "{0} -> {1} == {2} ?", o, i, rovar.derov(o));
			}			
		}
	}
}
